@@ -32,7 +32,7 @@ class EpicDetectorRecipe(Recipe):
         self.config['branch'] = 'main'
         self.config['branch_epic'] = self.config['branch']
         self.config['branch_ip6'] = 'master'    # https://github.com/eic/ip6/issues/1
-        self.required_deps = ['clhep', 'eigen3', 'root', 'hepmc3', 'podio', 'edm4hep', 'eicd', 'geant4', 'acts',  'dd4hep']
+        self.required_deps = ['clhep', 'eigen3', 'root', 'hepmc3', 'podio', 'edm4hep', 'eicd', 'geant4','dd4hep', 'acts', 'actsdd4hep' ]
         self.config['repo_address_epic'] = 'https://github.com/eic/epic'
         self.config['repo_address_ip6'] = 'https://github.com/eic/ip6'
 
@@ -156,6 +156,8 @@ class EpicDetectorRecipe(Recipe):
 
         yield Set('EIC_DD4HEP_HOME', data['built_with_config']['install_path_epic'])
         yield Set('IP6_DD4HEP_HOME', data['built_with_config']['install_path_ip6'])
+        yield Set('BEAMLINE_PATH', os.path.join(data['built_with_config']['install_path_ip6'],'share','ip6'))
+
 
     #
     # OS dependencies are a map of software packets installed by os maintainers
